#############################
Henson-Logging |build status|
#############################

.. |build status| image:: https://travis-ci.org/iheartradio/Henson-Logging.svg?branch=master
   :target: https://travis-ci.org/iheartradio/Henso-Logging

A library to use structured logging with a Henson application.

* `Documentation <https://henson-logging.rtfd.org>`_
* `Installation <https://henson-logging.readthedocs.org/en/latest/#installation>`_
* `Changelog <https://henson-logging.readthedocs.org/en/latest/changes.html>`_
* `Source <https://github.com/iheartradio/Henson-logging>`_
